#-*- coding: utf-8 -*-

import zope.component
from zope.component.interfaces import IComponentLookup
from zope.component.testlayer import ZCMLFileLayer
from zope.container.interfaces import ISimpleReadContainer
from zope.container.traversal import ContainerTraversable
from zope.interface import Interface
from zope.site.folder import rootFolder
from zope.site.site import LocalSiteManager, SiteManagerAdapter
from zope.traversing.interfaces import ITraversable
from zope.traversing.testing import setUp


class DolmenViewSelectorLayer(ZCMLFileLayer):

    def setUp(self):
        ZCMLFileLayer.setUp(self)
        zope.component.hooks.setHooks()
    
        # Set up site manager adapter
        zope.component.provideAdapter(
            SiteManagerAdapter, (Interface,), IComponentLookup)

        # Set up traversal
        setUp()
        zope.component.provideAdapter(
            ContainerTraversable, (ISimpleReadContainer,), ITraversable)

        # Set up site
        site = rootFolder()
        site.setSiteManager(LocalSiteManager(site))
        zope.component.hooks.setSite(site)

        return site

    def tearDown(self):
        zope.component.hooks.resetHooks()
        zope.component.hooks.setSite()
        ZCMLFileLayer.tearDown(self)



# -*- coding: utf-8 -*-

from zope.i18nmessageid import MessageFactory
MF = MessageFactory('dolmen.app.viewselector')

from dolmen.app.viewselector.interfaces import IViewSelector
from dolmen.app.viewselector.menu import SelectableViewsMenu



# -*- coding: utf-8 -*-

import grokcore.component as grok
from dolmen import menu
from dolmen.app.viewselector import MF as _, IViewSelector


class SelectableViewsMenu(menu.Menu):
    grok.name('selectable-views')
    grok.title(_(u'Content display'))
    grok.context(IViewSelector)
    menu_class = u"menu additional-actions"



#!/usr/bin/python
# -*- coding: utf-8 -*-

from zope.schema import TextLine
from zope.interface import Interface
from dolmen.app.viewselector import MF as _


class IViewSelector(Interface):
    """A component aware of dynamic views.
    """
    selected_view = TextLine(
        title=_(u"Selected View"),
        default=u"base_view",
        required=True,
        )



# -*- coding: utf-8 -*-

import doctest
import unittest
from dolmen.app.viewselector import tests
from zope.security.testing import Principal, Participation
from zope.security.management import newInteraction, endInteraction


def login(id, request=None):
    if request is None:
        participation = Participation(Principal(id))
        newInteraction(participation)
    else:
        principal = Principal(id)
        request.setPrincipal(principal)
        newInteraction(request)


def logout():
    endInteraction()


def test_suite():
    suite = unittest.TestSuite()
    readme = doctest.DocFileSuite(
        '../README.txt',
        globs={'login': login, 'logout': logout,
               '__name__': 'dolmen.app.viewselector.tests'},
        optionflags=(doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS))
    readme.layer = tests.DolmenViewSelectorLayer(tests)
    suite.addTest(readme)
    return suite



# -*- coding: utf-8 -*-

import grokcore.viewlet as grok
from grokcore import message
from megrok.layout import IPage
from dolmen.app.viewselector import MF as _, SelectableViewsMenu, IViewSelector
from dolmen.app.layout import Page, master
from dolmen.app.layout.viewlets import ContextualActions
from zope.component import queryMultiAdapter


class SelectedView(Page):
    grok.name("index")
    grok.context(IViewSelector)
    grok.require("dolmen.content.View")

    def render(self):
        rendering = queryMultiAdapter(
            (self.context, self.request), name=self.context.selected_view)
        if rendering is not None and IPage.providedBy(rendering):
            rendering.update()
            return rendering.content()
        return _(u"The selected view is not a valid IPage component.")


class ApplyView(grok.View):
    grok.name('viewselector')
    grok.context(IViewSelector)
    grok.require("dolmen.content.Edit")

    def render(self, name=None):
        if not name or name == 'index':
            message.send(
                _(u"This element can't be selected as the default view."))
        else:
            self.context.selected_view = name
            message.send(
                _(u"${name} has been selected as the default view.",
                  mapping={'name': name}))
        return self.redirect(self.url(self.context))


class SelectableViews(ContextualActions):
    grok.order(80)
    grok.context(IViewSelector)
    grok.viewletmanager(master.AboveBody)
    grok.require("dolmen.content.Edit")

    menu_factory = SelectableViewsMenu

    def compute_actions(self, viewlets):
        for action in viewlets:
            selected = action.__name__ == self.context.selected_view
            if not selected:
                url = "%s/@@viewselector?name=%s" % (
                    self.menu.context_url, action.__name__)
            else:
                url = None

            yield {
                'id': action.__name__,
                'url': url,
                'title': action.title,
                'selected': selected,
                'class': (selected and 'selected ' +
                          self.menu.entry_class or self.menu.entry_class),
                }



from setuptools import setup, find_packages
from os.path import join

name = 'dolmen.app.viewselector'
version = '1.0b1'
readme = open(join('src', 'dolmen', 'app', 'viewselector', "README.txt")).read()
history = open(join('docs', 'HISTORY.txt')).read().replace(name + ' - ', '')

setup(name = name,
      version = version,
      description = 'Dolmen Layout/View Selector',
      long_description = readme + '\n\n' + history,
      keywords = 'Grok Zope3 CMS Dolmen',
      author = 'Souheil Chelfouh',
      author_email = 'souheil@chelfouh.com',
      url = 'http://www.dolmen-project.org',
      download_url = 'http://pypi.python.org/pypi/dolmen.app.viewselector',
      license = 'GPL',
      packages=find_packages('src', exclude=['ez_setup']),
      package_dir={'': 'src'},
      namespace_packages = ['dolmen', 'dolmen.app'],
      include_package_data = True,
      platforms = 'Any',
      zip_safe = False,
      install_requires=[
          'dolmen.app.layout',
          'dolmen.menu',
          'grokcore.component',
          'grokcore.message',
          'grokcore.view',
          'grokcore.viewlet',
          'megrok.layout',
          'setuptools',
          'zope.component',
          'zope.i18n',
          'zope.i18nmessageid',
          'zope.interface',
          'zope.schema',
          ],
      extras_require = {'test': [
          'zope.container',
          'zope.location',
          'zope.principalregistry',
          'zope.publisher',
          'zope.security',
          'zope.securitypolicy',
          'zope.site',
          'zope.traversing',
          ]},
      classifiers = [
          'Environment :: Web Environment',
          'Framework :: Zope3',
          'License :: OSI Approved :: GNU General Public License (GPL)',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          ],
      )
